Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1)

Unified Diff: impl/dummy/dummy.go

Issue 2062613002: Add TrimmedAppID to info service. (Closed) Base URL: https://chromium.googlesource.com/external/github.com/luci/gae@master
Patch Set: Created 4 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: impl/dummy/dummy.go
diff --git a/impl/dummy/dummy.go b/impl/dummy/dummy.go
index e0c3fdac16e8d84b9e6f09801c33e932872efe69..64696c0347a2f270ca9cb35044e0410b972e82d9 100644
--- a/impl/dummy/dummy.go
+++ b/impl/dummy/dummy.go
@@ -83,7 +83,6 @@ func (ds) GetMulti([]*datastore.Key, datastore.MultiMetaGetter, datastore.GetMul
panic(ni())
}
func (ds) DeleteMulti([]*datastore.Key, datastore.DeleteMultiCB) error { panic(ni()) }
-func (ds) NewQuery(string) datastore.Query { panic(ni()) }
func (ds) DecodeCursor(string) (datastore.Cursor, error) { panic(ni()) }
func (ds) Count(*datastore.FinalizedQuery) (int64, error) { panic(ni()) }
func (ds) Run(*datastore.FinalizedQuery, datastore.RawRunCB) error { panic(ni()) }
@@ -154,7 +153,6 @@ func (i) ServiceAccount() (string, error)
func (i) SignBytes(bytes []byte) (keyName string, signature []byte, err error) { panic(ni()) }
func (i) VersionID() string { panic(ni()) }
func (i) Namespace(namespace string) (context.Context, error) { panic(ni()) }
-func (i) MustNamespace(namespace string) context.Context { panic(ni()) }
func (i) Datacenter() string { panic(ni()) }
func (i) InstanceID() string { panic(ni()) }
func (i) IsDevAppServer() bool { panic(ni()) }
@@ -166,10 +164,10 @@ func (i) Testable() info.Testable
var dummyInfoInst = i{}
// Info returns a dummy info.Interface implementation suitable for embedding.
// Every method panics with a message containing the name of the method which
// was unimplemented.
-func Info() info.Interface { return dummyInfoInst }
+func Info() info.RawInterface { return dummyInfoInst }
////////////////////////////////////// u ///////////////////////////////////////
« no previous file with comments | « filter/featureBreaker/gi.go ('k') | impl/memory/info.go » ('j') | service/info/wrapper.go » ('J')
@@ -166,10 +164,10 @@ func (i) Testable() info.Testable
var dummyInfoInst = i{}
-// Info returns a dummy info.Interface implementation suitable for embedding.
+// Info returns a dummy info.RawInterface implementation suitable for embedding.
// Every method panics with a message containing the name of the method which
// was unimplemented.

Powered by Google App Engine
This is Rietveld 408576698